/*
  Name : alert.cpp
  Copyright : KPAMEGAN & ROUSSET
  Authors : KPAMEGAN Karel, ROUSSET Baptiste
  Description: file which contents functions to generate alerts on a LCD screen
*/

#include "alert.hpp"
#include "initTimer.hpp"

/*********************************************EXTERN*******************************************/

extern InitTimes confTimes; //contents the number of blinking of the title, comes from main.cpp

/*****************************************FUNCTIONS*******************************************/

void nano(int speed);

/*****************************************METHODS**********************************************/

/*
  Name : Alert
  Finality : this is a constructor
  Decription : create an effect screen,
               set on the top of the first screen "ALERTE"
*/
Alert::Alert()
{
  effect= new Effect(this);
  set_title("ALERTES");
}

/*
  Name : Alert
  Finality : this is a constructor
  Decription : create an effect screen,
               set on the top of the first screen his title which is given on argument
*/
Alert::Alert(char *newTitle)
{
  effect= new Effect(this);
  set_title(newTitle);
}

/*
  Name : ~Alert
  Finality : this is the destructor
  Decription : delete the effect screen,
               clen the list of the alert
*/
Alert::~Alert()
{
  delete effect;
  clean_Alert();
}

/*
  Name : add_Alert
  Finality : add an alert into the list
  Decription : add an alert given on argument into the list of alerts
*/
void Alert::add_Alert(char *alert)
{
  listAlert.push_back(alert);
}

/*
  Name : clean_Alert
  Finality : clear the list of all the alerts
  Decription : clean the list of all the alerts,
               set line1/2/3 to empty lines,
               set stars arround the screen
*/
void Alert::clean_Alert(void)
{
  char txt [2]=" ";
  listAlert.clear();
  set_line_center(1,txt);
  set_line_center(2,txt);
  set_line_center(3,txt);
  set_stars();
}

/*
  Name : set_title
  Finality : set the title of the screen
  Description : set the title given on argument to the screen
*/
void Alert::set_title(char *newTitle)
{
  title=newTitle;
  set_line_center(0,newTitle);
}


/*
  Name : show_Alert
  Finality : display the alerts
  Decription : if there are severals alerts the title of the screen will be "ALERTES",
               else it will be "ALERTE",
               we display all the alerts of the list three by three
*//*
 int Alert::show_Alert(void)
{
  char tab1[18],tab2[18];
  if ( listAlert.size() == 0 ) return 0;
  int last=14;
  if ( listAlert.size() > 1 )
    {
      set_line_center(0,"ALERTES");
      last=14;
    }
  else set_line_center(0,"ALERTE");
  int i=1,j,k;
  list<char *>::iterator it;
  for(it=listAlert.begin();it!=listAlert.end();it++)
    {
      if(i==4)
	{
	  set_stars();
	  effect->show_screen();
	  effect->blink_area(7,last,0,0,3);
	  nano(1);
	  effect->disappear_screen_down();
	  nano(1);
	  set_line_center(1," ");
	  set_line_center(2," ");
	  set_line_center(3," ");
	  i=1;
	}
      if((strlen(*it))>18)
      {
      	for ( j=0;j<18;j++ )
	  tab1[j]=(*it)[j];
	for (k=0;j<(strlen(*it));j++,k++)
	  tab2[k]=(*it)[j];
	tab2[j+1]='\0';
	set_line_center(i,tab1);
	i++;
	if(i==4)
	{
	  set_stars();
	  effect->show_screen();
	  effect->blink_area(7,last,0,0,3);
	  nano(1);
	  effect->disappear_screen_down();
	  nano(1);
	  set_line_center(1," ");
	  set_line_center(2," ");
	  set_line_center(3," ");
	  i=1;
	}
	set_line_center(i,tab2);
	i++;
	printf("alert too long\n"),exit(0);
      }
      else 
        {
	  set_line_center(i,(*it));
          i++;
	}
    }
  set_stars();
  effect->show_screen();
  effect->blink_area(7,last,0,0,3);
  return 1;
}
 */

int Alert::show_Alert(void)
{
  int j=0;
  char tab1[18];
  if ( listAlert.size() == 0 ) return 0;
  int i=1;
  list<char *>::iterator it;
  for(it=listAlert.begin();it!=listAlert.end();it++)
    {
      if(i==4)
	{
	  set_stars();
	  effect->show_screen();
	  effect->blink_area(1,18,0,0,confTimes.get_numberBlinkTitle()); //blink confTimes.get_numberBlinkTitle() times
	  nano(1);
	  effect->disappear_screen_down();
	  nano(1);
	  set_line_center(1," ");
	  set_line_center(2," ");
	  set_line_center(3," ");
	  i=1;
	}
      if((strlen(*it))>18)
        {
          for ( j=0;j<18;j++ )
	    tab1[j]=(*it)[j];
	  set_line_center(i,tab1);
	  i++;
	}
      else 
        {
	  set_line_center(i,(*it));
          i++;
	}
    }
  set_stars();
  effect->show_screen();
  effect->blink_area(1,18,0,0,confTimes.get_numberBlinkTitle());//blink confTimes.get_numberBlinkTitle() times
  return 1;
}
 
