/*
  Name : automaton.hpp
  Copyright : MARTY & FOK
  Authors : MARTY Sbastien & FOK Pierre
  Description: file which contents functions of the automaton
*/

#ifndef _AUTOMATON_HPP_
#define _AUTOMATON_HPP_

#include "blue.hpp"
#include "carte.hpp"
#include "hqi.hpp"
#include "lampes.hpp"
#include "peristatic.hpp"
#include "pump.hpp"
#include "rah.hpp"
#include "skimmer.hpp"
#include "temperature.hpp"
#include "osmolation.hpp"
#include "param.h"
#include "util.h"
#include "ventilator.hpp"


class Automaton
{
private:
  
  //pointer on all modules
  HQI *hqi;
  Blue *blue;
  Pump *pump;
  Temperature *temperature;
  Skimmer *skimmer;
  Peristatic *peristatic;
  Rah *rah;
  Osmolation *osmolation;
  Ventilator *ventilator;

public:

  //Attributes
  short getstart;	//state of the automaton
  
  HQI * getHqi(){return hqi;}
  Blue * getBlue(){return blue;}
  Pump * getPump(){return pump;}
  Temperature * getTemperature(){return temperature;}
  Skimmer * getSkimmer(){return skimmer;}
  Peristatic * getPeristatic(){return peristatic;}
  Rah * getRah(){return rah;}
  Osmolation * getOsmolation(){return osmolation;}
  Ventilator * getVentilator(){return ventilator;}
  
  
  //Methods
  Automaton();
  ~Automaton();
  void init();		//initialize the automaton and all its modules
  void restart (connexion &);	//restart the automaton

  void getInputState(K8055 &,config&);	//get the state all input modules
  


};

#endif
